@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Crea Prezzi":  				$messaggio = "Criar preços"; break;
 case "Inserisci i prezzi per l'anno":  		$messaggio = "Inserir os preços do ano"; break;
 case "Prezzi della":  				$messaggio = "Preços da"; break;
 case "tariffa":  				$messaggio = "tarifa"; break;
@@ -14,9 +15,9 @@ case "Costi aggiuntivi":  			$messaggio = "Custos adicionais"; break;
 case "Nome del nuovo costo aggiuntivo":		$messaggio = "Nome do novo custo adicional"; break;
 case "da applicare":  				$messaggio = "para aplicar"; break;
 case "sempre":  				$messaggio = "sempre"; break;
-case "su richiesta":  				$messaggio = "quando pedido"; break;
+case "su richiesta":  				$messaggio = "sobre pedido"; break;
 case "chiedi per quanto deve essere moltiplicato":	$messaggio = "perguntar por quanto deve ser multiplicado"; break;
-case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considerar este custo único como cama(s) extra(s)"; break;
+case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considerar o custo final como cama(s) extra(s)"; break;
 case "numero di settimane":  			$messaggio = "número de semanas"; break;
 case "numero di giorni":  			$messaggio = "número de dias"; break;
 case "tutte":  					$messaggio = "todas"; break;
@@ -30,7 +31,6 @@ case "della tariffa arrotondato a":  		$messaggio = "da tarifa arredondada a"; b
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considerar este custo percentual como cama(s) extra(s)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Progridir com a inserção do novo custo adicional"; break;
 case "Caparra":  				$messaggio = "Depósito"; break;
-case "La caparra normale per la":  		$messaggio = "O depósito normal pela"; break;
 case "arrotondata a":  				$messaggio = "arredondado a"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Inserir ou alterar o depósito"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "Visualizar os preços já inseridos"; break;
@@ -76,9 +76,9 @@ case "I soldi del costo settimanale sono sbagliati":	$messaggio = "O valor do cu
 case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "O valor do custo diário está errado"; break;
 case "I soldi del costo percentuale sono sbagliati":	$messaggio = "O valor do custo percentual está errado"; break;
 case "Inserzione per settimane":  		$messaggio = "Introdução por semanas"; break;
-case "Inserzione per giorni":			$messaggio = "Inserção por dias"; break;
-case "Inserzione per settimane":  		$messaggio = "Inserção por semana"; break;
-case "Settimane dal":  				$messaggio = "Semanas do"; break;
+case "Inserzione per giorni":			$messaggio = "Inserção diário"; break;
+case "Inserzione per settimane":  		$messaggio = "Inserção semanal"; break;
+case "Settimane dal":  				$messaggio = "Semanal de"; break;
 case "Dom/Lun":  				$messaggio = "Dom/Seg"; break;
 case "Lun/Mar":  				$messaggio = "Seg/Ter"; break;
 case "Mar/Mer":  				$messaggio = "Ter/Qua"; break;
@@ -230,7 +230,6 @@ case "La caparra è errata":  			$messaggio = "O depósito está errado"; break;
 case "è":  					$messaggio = "é"; break;
 case "il":  					$messaggio = "o"; break;
 case "Commissioni":  				$messaggio = "Comissões"; break;
-case "Le commissioni normali sulla":  		$messaggio = "Comissões normais sobre a"; break;
 case "sono":  					$messaggio = "são"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Inserir ou alterar as comissões"; break;
 case "Tasse":  					$messaggio = "Taxas"; break;
@@ -254,6 +253,9 @@ case "il prezzo della tariffa per le prime":  	$messaggio = "o preço da tarifa
 case "della":  					$messaggio = "da"; break;
 case "tariffa + sconto":  			$messaggio = "tarifa + desconto"; break;
 case "tariffa + sconto + costi agg.":  		$messaggio = "tarifa + desconto + custos adicionais"; break;
+case "della tar.":  				$messaggio = "da tarifa"; break;
+case "di t.+s.":  				$messaggio = "da tarifa + desconto"; break;
+case "di t.+s.+c.a.":  				$messaggio = "da tarifa + desconto + comissão + custos adicionais"; break;
 case "Nome della":  				$messaggio = "Nome da"; break;
 case "Cambia":  				$messaggio = "Alterar"; break;
 case "prezzo per settimana":  			$messaggio = "preço por semana"; break;
@@ -273,7 +275,7 @@ case "opzionale":  				$messaggio = "opcional"; break;
 case "Costi combinati":  			$messaggio = "Custos combinados"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Entrada rápida de um novo custo adicional para"; break;
 case "permanenza minima":  			$messaggio = "estadia mínima"; break;
-case "numero di bambini":  			$messaggio = "número de crianças"; break;
+case "numero di neonati":  			$messaggio = "número de bebés"; break;
 case "letto aggiuntivo":  			$messaggio = "cama extra"; break;
 case "offerta speciale":  			$messaggio = "oferta especial"; break;
 case "inserisci":  				$messaggio = "adicionar"; break;
@@ -281,10 +283,10 @@ case "Inserisci il costo aggiuntivo":  		$messaggio = "Inserir o custo adicional
 case "Numero minimo di giorni":  		$messaggio = "Número mínimo de dias"; break;
 case "Applicato alle tariffe":  		$messaggio = "Aplicado às tarifas"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Períodos em que será aplicado o custo"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Valor de desconto por cada criança"; break;
+case "Valore per ogni neonato":  		$messaggio = "Valor por bebé"; break;
 case "del prezzo di una persona":  		$messaggio = "do preço de uma pessoa"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "apenas por tarifas com preços por pessoa"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "com esse custo você deve incluir o número de crianças também no número de pessoas"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "com este custo, o número de bebés não está incluído no número de hospedes"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Valor da cama extra"; break;
 case "Valore dello sconto":  			$messaggio = "Valor do desconto"; break;
 case "del prezzo totale":  			$messaggio = "do preço total"; break;
@@ -304,6 +306,31 @@ case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo per
 case "tutte le tariffe":  			$messaggio = "todas as tarifas"; break;
 case "considerare l'intero costo come tasse":  	$messaggio = "considerar o inteiro custo como taxas"; break;
 case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Excluir este custo do total por outros custos porcentuais"; break;
+case "in tutti i periodi in modo predefinito":	$messaggio = "em todos os períodos em modo padrão"; break;
+case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "importar os preços de outras tarifas (não podera exportar estes preços)"; break;
+case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "já está importando preços de outras tarifas, portanto não pode importar estes preços"; break;
+case "modifica":  				$messaggio = "modificar"; break;
+case "In modo predefinito importa":  		$messaggio = "Importar por padrão"; break;
+case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "os preços de alguns períodos <em>não foram inseridos</em> porque eles foram importados por outras tarifas já"; break;
+case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limite não considerado para pessoas adicionais nas interligações"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Agora selecione esse custo também para todos os usuários que não têm privilégios para usar todos os custos"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Adicione este custo agora à todas as páginas web criadas"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "Multiplicando-se com o númer de pessoas"; break;
+case "escludi":  				$messaggio = "exclua"; break;
+case "includi solo":  				$messaggio = "incluem apenas"; break;
+case "questi tipi":  				$messaggio = "estes tipos"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Mostrar como um tipo de pessoa"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Aplicar a percentagem do tipo de pessoa ao preço do custo"; break;
+case "Neonati (0-23 mesi)":  			$messaggio = "Bebês (0-23 meses)"; break;
+case "tariffe con":  				$messaggio = "tarifas com"; break;
+case "a":  					$messaggio = "ao"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
