@@ -2,9 +2,10 @@
 
 switch ($messaggio) {
 
+case "Tabelle Mesi":  				$messaggio = "Tabela dos meses"; break;
 case "situazione alle":  			$messaggio = "situação às"; break;
 case "del":  					$messaggio = "do"; break;
-case "Tabella prenotazioni del":  		$messaggio = "Tabela das reservas do"; break;
+case "Tabella prenotazioni del":  		$messaggio = "Tabela reservas do"; break;
 case "ERRORE":  				$messaggio = "ERRO"; break;
 case "Torna al menù principale":  		$messaggio = "Voltar ao menu pincipal"; break;
 case "Visualizza la tabella normale":  		$messaggio = "Visualizar a tabela normal"; break;
