@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Visualizza Tabelle":  			$messaggio = "Exibir tabelas"; break;
 case "Vedi le prenotazioni":  			$messaggio = "Visualizar as reservas"; break;
 case "presenti dal":  				$messaggio = "atuais de"; break;
 case "al":  					$messaggio = "a"; break;
@@ -111,9 +112,9 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Você tem certeza que deseja <b>apagar</b> a regra de atribuição 4 pela"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "A regra de atribuição foi apagada"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "A regra de atribuição já era apagada"; break;
-case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabela com as regras de atribuição 1 do"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Tabela com as regras de atribuição"; break;
+case "del":					$messaggio = "do"; break;
 case "Motivazione":  				$messaggio = "Razão"; break;
-case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabela com as regras de atribuição 2 do"; break;
 case "Tariffa":  				$messaggio = "Tarifa"; break;
 case "Inserisci nuove regole":  		$messaggio = "Inserir novas regras"; break;
 case "Il numero inserito esiste già":  		$messaggio = "O número inserido já existe"; break;
@@ -166,7 +167,6 @@ case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "d
 case "Profilo":  				$messaggio = "Perfil"; break;
 case "Cliente":  				$messaggio = "Cliente"; break;
 case "cliente":  				$messaggio = "cliente"; break;
-case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabela com as regras de atribuição 3 do"; break;
 case "Utente":  				$messaggio = "Usuário"; break;
 case "Periodi_permessi":  			$messaggio = "Períodos concedidos"; break;
 case "unico":  					$messaggio = "único"; break;
@@ -219,7 +219,6 @@ case "Applica i cambiamenti":  			$messaggio = "Aplicar alterações"; break;
 case "documento di tipo":  			$messaggio = "documento do tipo"; break;
 case "visualizza":  				$messaggio = "visualizar"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "Visualizar todas as reservas"; break;
-case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabela com as regras de atribuição 4 do"; break;
 case "Numero di persone":  			$messaggio = "Número de pessoas"; break;
 case "assegna_se_":  				$messaggio = "atribuir se "; break;
 case "più_di_":  				$messaggio = "mais de "; break;
@@ -356,10 +355,36 @@ case "chiusa":  				$messaggio = "fechada"; break;
 case "presenti in data":  			$messaggio = "presente na data"; break;
 case "comprese partenze":  			$messaggio = "incluindo saídas"; break;
 case "escludere_da_totale_percentuale":  	$messaggio = "excluir do total percentual"; break;
+case "da varie tariffe":  			$messaggio = "de várias tarifas"; break;
+case "senza letti aggiuntivi":  		$messaggio = "sem camas adicionais"; break;
+case "Premere per modificare":  		$messaggio = "Clique para modificar"; break;
+case "Converti definitivamente in":  		$messaggio = "Definitivamente convertido em"; break;
+case "al cambio attuale":  			$messaggio = "na taxa de câmbio atual"; break;
+case "Le altre valute presenti nella cassa":  	$messaggio = "As outras moedas presentes no caixa"; break;
+case "sono state convertite in":  		$messaggio = "foram convertidos para"; break;
+case "Tabella con le prenotazioni cancellate":	$messaggio = "Tabela com reservas canceladas"; break;
+case "<b>non importare</b> i prezzi":  		$messaggio = "<b>não importe</b> preços"; break;
+case "Attenzione":  				$messaggio = "Atenção"; break;
+case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "os períodos adicionados não poderão mais ser eliminados"; break;
+case "come tipo di persona":  			$messaggio = "como tipo de pessoa"; break;
+case "e applica la % del tipo di persona":  	$messaggio = "e aplique a % do tipo de pessoa"; break;
+case "escludendo":  				$messaggio = "excluindo"; break;
+case "includendo solo":  			$messaggio = "incluindo apenas"; break;
+case "e":  					$messaggio = "e"; break;
+case "Superato il massimo numero di anni comparabili":	$messaggio = "Superou o número máximo de anos comparáveis"; break;
+case "Numero_predefinito di persone":  		$messaggio = "Número_predefinido de pessoas"; break;
+case "Numero_minimo di persone":  		$messaggio = "Número_mínimo de pessoas"; break;
+case "Id":  					$messaggio = "Id"; break;
+case "chiedere":  				$messaggio = "ask"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Reservas canceladas"; break;
 case "TOTALE":  				$messaggio = "TOTAL"; break;
+case "Cancellare anche":  			$messaggio = "Delete also"; break;
+case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
+case "Anche cancellate":  			$messaggio = "Also deleted"; break;
+case "Solo cancellate":  			$messaggio = "Only deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
